@@ -14,7 +14,7 @@ from win32api import GetSystemMetrics
 from ..resources.language import Text
 from .measurement_import import Measurement
 from .ptw_import import PTWMultimporter
-from .sim_import import Simulation
+from .sim_import import EGSSimulation, Simulation
 
 
 class DoseFigureHandler:
@@ -23,73 +23,162 @@ class DoseFigureHandler:
         self.parent = parent
 
         self.norm = self.parent.norm.get()
+        self.normvalue = "max"
+        self.errorbars = True
+        self.caxcorrection = False
         self.zoom = self.parent.zoom.get()
         self.half = self.parent.half.get()
+        self.axlims = (self.parent.axlims.get(), self.parent.axlims.get())
         self.addmenu = False
 
         # Initialize the current settings
         self.lang = self.parent.lang
         self.text = Text()
         self.style = plt.style.use("default")
-        self.current_mode = self.parent.dark.get()
-        self.colors = {
-            False: ["#ffa43c", "#ff2e1b", "#1bff67", "#ff5cf1", "#493cff"],
-            True: ["#ff7fff", "#ffff00", "#00ffff", "#ff4040", "#40ff40"],
-        }
+        self.colors = ["#009F6B", "#C40233", "#00008B", "#BCA136", "#654321"]
         self.marker = "o--"
         self.markersize = self.parent.profile.get_attribute("markersize")
         self.linewidth = self.parent.profile.get_attribute("linewidth")
-        # Initialize the figure and axes
-        self.fig = Figure(figsize=(10, 5), constrained_layout=True, dpi=600)
-        self.canvas = FigureCanvasAgg(self.fig)
-        self.fig.set_canvas(self.canvas)
-        self.ax = self.fig.add_subplot(111)
 
         # Initialize necessary variables
         self.props = dict(boxstyle="round", facecolor="wheat", alpha=0.6)
         self.plots = []
         self.data = []
 
+    def add_plot_data(self, datanames):
+
+        """Adds data to the plot queue
+        """
+
+        test = [plotdata.direction for plotdata in self.plots]
+        for tuple in datanames:
+            filename = tuple[0]
+            type = tuple[1]
+            if filename not in [plotdata.filepath for plotdata in self.plots]:
+                if type == "simulation":
+                    sim = Simulation(filename)
+                    if test == []:
+                        self.plots += [sim]
+                    elif sim.direction == "Z" and "Z" in test:
+                        self.plots += [sim]
+                    elif sim.direction == "X" and "X" in test or "Y" in test:
+                        self.plots += [sim]
+                    elif sim.direction == "Y" and "X" in test or "Y" in test:
+                        self.plots += [sim]
+
+                    else:
+                        sd.messagebox.showinfo(
+                            "", f"{sim.filename}" + self.text.incordata[self.lang][1]
+                        )
+
+                elif type == "egs":
+                    sim = EGSSimulation(filename)
+                    ##!!!###
+
+                elif type == "ptw":
+                    importer = PTWMultimporter(filename, self.parent)
+                    importer.window.mainloop()
+                    importer.window.destroy()
+                    measurements = [plot for plot in importer.plots]
+                    fails = []
+                    for plot in measurements:
+                        if test == []:
+                            self.plots += [plot]
+                        elif plot.direction == "Z" and "Z" in test:
+                            self.plots += [plot]
+                        elif plot.direction == "X" and "X" in test or "Y" in test:
+                            self.plots += [plot]
+                        elif plot.direction == "Y" and "X" in test or "Y" in test:
+                            self.plots += [plot]
+                        else:
+                            fails += [plot]
+
+                    if fails != []:
+                        self.parent.filenames.pop(-1)
+                        names = ""
+                        for f in fails:
+                            names += str(f.filename) + ", "
+                        names = names[:-2]
+                        var = 1
+                        if len(fails) >= 2:
+                            var = 2
+                        sd.messagebox.showinfo(
+                            "", f"{names}" + self.text.incordata[self.lang][var],
+                        )
+
+                    del importer
+
+                else:
+                    self.plots += [Measurement(filename, type)]
+
+        if self.plots[0].direction == "Z":
+            self.half = False
+
+        for plotdata in self.plots:
+            if self.norm == True:
+                if self.normvalue == "max":
+                    plotdata.normpoint = max(plotdata.dose[self.half])
+                elif self.normvalue == "flank":
+                    plotdata.normpoint = max(plotdata.dose[self.half]) * 0.5
+                else:
+                    plotdata.normpoint = plotdata.dose[self.half][
+                        len(plotdata.dose) // 2
+                    ]
+
+            else:
+                plotdata.normpoint = 1
+            self.data += [
+                [
+                    plotdata.axis[self.half],
+                    plotdata.direction,
+                    plotdata.dose[self.half] / plotdata.normpoint,
+                    np.array(
+                        [x / plotdata.normpoint for x in plotdata.std_dev[self.half]]
+                    ),
+                ]
+                + plotdata.params
+            ]
+
+        if self.plots[0].direction == "Z":
+            figsize = (10, 5)
+        else:
+            figsize = (10, 6)
+
+        # Initialize the figure and axes
+        self.fig = Figure(figsize, constrained_layout=True, dpi=600)
+        self.canvas = FigureCanvasAgg(self.fig)
+        self.fig.set_canvas(self.canvas)
+        self.ax = self.fig.add_subplot(111)
+
+        return
+
     def set_style(self):
 
-        """
-        Switches the plotting style accordung to the current theme
+        """Switches the plotting style according to the current theme
         """
 
-        if self.parent.dark.get() != self.current_mode:
+        if self.parent.dark.get() == True:
+            self.ax.set_facecolor("#363636")
+            self.fig.set_facecolor("#363636")
+        else:
 
-            if self.parent.dark.get() == True:
-                try:
-                    self.ax.set_facecolor("#363636")
-                    self.fig.set_facecolor("#363636")
+            self.ax.set_facecolor("#ffffff")
+            self.fig.set_facecolor("#ffffff")
 
-                except AttributeError:
-                    pass
-            else:
-                try:
-                    self.ax.set_facecolor("#ffffff")
-                    self.fig.set_facecolor("#ffffff")
-
-                except AttributeError:
-                    pass
-
-            self.current_mode = self.parent.dark.get()
-
-            if self.plots != []:
-                self.parent.show_preview()
+        return
 
     def flush(self):
 
-        """
-        Clears the data
+        """Clears the data
         """
 
         self.data = []
 
+        return
+
     def fits(self, image):
 
-        """
-        Scales an image to the width of the screen.
+        """Scales an image to the width of the screen.
         """
 
         scr_width = GetSystemMetrics(0)
@@ -105,8 +194,7 @@ class DoseFigureHandler:
 
     def set_axis(self):
 
-        """
-        Defines the layout and gridlines of the plot 
+        """Defines the layout and gridlines of the plot 
         """
 
         self.ax.clear()
@@ -116,77 +204,11 @@ class DoseFigureHandler:
         self.ax.yaxis.set_minor_locator(AutoMinorLocator())
         self.ax.tick_params(axis="both", which="minor", length=2)
 
-    def add_plot_data(self, datanames):
-
-        """
-        Adds data to the plot queue
-        """
-
-        test = [plotdata.direction for plotdata in self.plots]
-        for tuple in datanames:
-            filename = tuple[0]
-            type = tuple[1]
-            if filename not in [plotdata.filepath for plotdata in self.plots]:
-                if type == "simulation":
-                    sim = Simulation(filename)
-                    if test == []:
-                        self.plots += [sim]
-                    elif sim.direction in test:
-                        self.plots += [sim]
-                    else:
-                        sd.messagebox.showinfo(
-                            "", f"{sim.filename}" + self.text.incordata[self.lang][1]
-                        )
-                elif type == "ptw":
-                    importer = PTWMultimporter(filename, self.parent.parent)
-                    importer.window.mainloop()
-                    importer.window.destroy()
-                    measurements = [plot for plot in importer.plots]
-                    fails = []
-                    for plot in measurements:
-                        if test == []:
-                            self.plots += [plot]
-                            test += [plotdata.direction for plotdata in self.plots]
-                        elif plot.direction in test:
-                            self.plots += [plot]
-                            test += [plotdata.direction for plotdata in self.plots]
-                        else:
-                            fails += [plot]
-
-                    if fails != []:
-                        names = ""
-                        for f in fails:
-                            names += str(f.filename) + ", "
-                        names = names[:-2]
-                        var = 1
-                        if len(fails) >= 2:
-                            var = 2
-                        sd.messagebox.showinfo(
-                            "", f"{names}" + self.text.incordata[self.lang][var],
-                        )
-                    del importer
-
-                else:
-                    self.plots += [Measurement(filename, type)]
-
-        if self.plots[0].direction == "Z":
-            self.half = False
-
-        for plotdata in self.plots:
-            self.data += [
-                [
-                    plotdata.axis[self.half],
-                    plotdata.direction,
-                    plotdata.dose[self.half][self.norm],
-                    plotdata.std_dev[self.half][self.norm],
-                ]
-                + plotdata.params
-            ]
+        return
 
     def add_legend(self):
 
-        """
-        Adds the legend
+        """Adds the legend
         """
 
         self.ax.legend(
@@ -197,11 +219,33 @@ class DoseFigureHandler:
             fancybox=True,
         )
 
+        return
+
     def add_descriptors(self):
 
+        """Adds the calculated parameters as descriptors
         """
-        Adds the calculated parameters as descriptors
-        """
+
+        if self.plots[0].direction != "Z":
+
+            if self.half == False:
+                positionsx = [
+                    0.1,
+                    0.1,
+                    0.901,
+                    0.901,
+                    0.1,
+                ]
+                positionsy = [0.98, 0.68, 0.75, 0.45, 0.38]
+            else:
+                positionsx = [
+                    0.7,
+                    0.7,
+                    0.901,
+                    0.901,
+                    0.7,
+                ]
+                positionsy = [0.98, 0.68, 0.68, 0.38, 0.38]
 
         for index, plot_data in enumerate(self.data):
 
@@ -217,13 +261,13 @@ class DoseFigureHandler:
                     space += 0.01
                 self.ax.text(
                     0.795 + space,
-                    0.7 - 0.1 * index,
+                    0.955 - len(self.plots) * 0.0475 - 0.1 * index,
                     textstr,
                     transform=self.ax.transAxes,
                     fontsize=10,
                     verticalalignment="top",
                     bbox=self.props,
-                    color=self.colors[self.current_mode][index],
+                    color=self.colors[index],
                 )
             else:
                 (
@@ -247,6 +291,10 @@ class DoseFigureHandler:
                     plot_data[11],
                     plot_data[12],
                 )
+
+                if self.caxcorrection == True:
+                    CAXdev = 0
+
                 textstr = "{} = {} mm\n{} = {} mm\n{} = {}\n{} = {}\n{} = {} mm\n{} = {} mm\n{} = {}\n{} = {}\n{} = {}".format(
                     self.text.fwhm[self.lang],
                     HWB,
@@ -267,53 +315,68 @@ class DoseFigureHandler:
                     self.text.symmetry[self.lang],
                     S,
                 )
-
                 self.ax.text(
-                    (0.6 - 0.1 * len(self.data)) + 0.2 * index,
-                    0.5,
+                    positionsx[index],
+                    positionsy[index],
                     textstr,
                     transform=self.ax.transAxes,
                     fontsize=10,
                     verticalalignment="top",
                     bbox=self.props,
                     horizontalalignment="center",
-                    color=self.colors[self.current_mode][index],
+                    color=self.colors[index],
                 )
 
+        return
+
     def set_x_label(self):
 
+        """Names the x-axis according to the plot type
         """
-        Names the x-axis according to the plot
-        """
-        xlabel = "{}-{} [mm]".format(self.data[0][1], self.text.axis[self.lang])
+
+        directions = [plot.direction for plot in self.plots]
+        if directions.count(directions[0]) == len(directions):
+
+            xlabel = f"{directions[0]}-{self.text.axis[self.lang]} [mm]"
+        else:
+            xlabel = f"X- {self.text.orr[self.lang]} Y-{self.text.axis[self.lang]}"
+
         self.ax.set_xlabel(xlabel, size=12)
         if self.norm == False:
             self.ax.set_ylabel(self.plots[0].unit, size=12)
 
+        return
+
     def create_plots_from_data(self):
 
-        """
-        Creates the plots from the queue
+        """Creates the plots from the queue
         """
 
         for index, plot_data in enumerate(self.data):
-            self.ax.errorbar(
-                x=plot_data[0],
-                y=plot_data[2],
-                yerr=plot_data[3],
-                fmt="none",
-                ecolor="black",
-                elinewidth=0.5,
-                capsize=1,
-                capthick=0.2,
-                ms=2,
-            )
+            if self.caxcorrection == True:
+                plot_data[0] = [x - plot_data[5] for x in plot_data[0]]
+
+            if self.errorbars == True:
+                try:
+                    self.ax.errorbar(
+                        x=plot_data[0],
+                        y=plot_data[2],
+                        yerr=plot_data[3],
+                        fmt="none",
+                        ecolor=self.colors[index],
+                        elinewidth=0.625,
+                        capsize=1.25,
+                        capthick=0.25,
+                        ms=2.5,
+                    )
+                except ValueError:
+                    pass
             self.ax.plot(
                 plot_data[0],
                 plot_data[2],
                 self.marker,
                 markersize=self.markersize,
-                color=self.colors[self.current_mode][index],
+                color=self.colors[index],
                 linewidth=self.linewidth,
                 label=f"{self.plots[index].filename}",
             )
@@ -323,6 +386,18 @@ class DoseFigureHandler:
         except:
             pass
 
+        self.axlims = (self.parent.axlims.get(), self.parent.axlims.get())
+        if self.plots[0].direction == "Z" or self.half == True:
+            self.axlims = (0, self.axlims[1])
+        self.ax.set_xlim(
+            left=self.ax.get_xlim()[0] - self.axlims[0],
+            right=self.ax.get_xlim()[1] + self.axlims[1],
+        )
+        self.ax.set_xbound(
+            lower=self.ax.get_xlim()[0] - self.axlims[0],
+            upper=self.ax.get_xlim()[1] + self.axlims[1],
+        )
+
         if self.zoom == True:
 
             self.canvas.draw()
@@ -363,27 +438,35 @@ class DoseFigureHandler:
                 y[self.plots[-1].axis[self.half].index(self.focuspoint)] / height
             )
 
-            self.axins = inset_axes(self.ax, "28%", "28%", loc="lower left")
+            loc = "lower left"
+            if self.half == False and self.plots[0].direction != "Z":
+                loc = "lower center"
+
+            self.axins = inset_axes(self.ax, "28%", "28%", loc=loc)
             yvalsat195 = []
             yvalsat205 = []
             for index, plot_data in enumerate(self.data):
-                self.axins.errorbar(
-                    x=plot_data[0],
-                    y=plot_data[2],
-                    yerr=plot_data[3],
-                    fmt="none",
-                    ecolor="black",
-                    elinewidth=0.5,
-                    capsize=1,
-                    capthick=0.2,
-                    ms=2,
-                )
+                if self.errorbars == True:
+                    try:
+                        self.axins.errorbar(
+                            x=plot_data[0],
+                            y=plot_data[2],
+                            yerr=plot_data[3],
+                            fmt="none",
+                            ecolor=self.colors[index],
+                            elinewidth=0.625,
+                            capsize=1.25,
+                            capthick=0.25,
+                            ms=2.5,
+                        )
+                    except ValueError:
+                        pass
                 self.axins.plot(
                     plot_data[0],
                     plot_data[2],
                     self.marker,
                     markersize=self.markersize,
-                    color=self.colors[self.current_mode][index],
+                    color=self.colors[index],
                     linewidth=self.linewidth,
                     label=f"{self.plots[index].filename}",
                 )
@@ -426,21 +509,23 @@ class DoseFigureHandler:
 
             mark_inset(self.ax, self.axins, loc1=2, loc2=4, fc="none", ec="0.5")
 
+        return
+
     def return_figure(self, filenames):
 
-        """
-        Passes the image of the plot and the plot type to the MainApplication
+        """Passes the image of the plot and the plot type to the MainApplication
         """
 
         self.half = self.parent.half.get()
+        self.add_plot_data(filenames)
 
         self.set_axis()
-        self.add_plot_data(filenames)
-        self.set_style()
         self.set_x_label()
         self.create_plots_from_data()
-        self.add_legend()
         self.add_descriptors()
+        self.add_legend()
+        self.ax.set_aspect("auto")
+        self.set_style()
 
         self.canvas.draw()
         buffer = self.canvas.buffer_rgba()
