@@ -12,7 +12,7 @@ class Simulation:
     def __init__(self, filepath):
 
         self.filepath = filepath
-        self.filename = self.filepath.split("/")[-1]
+        self.filename = self.filepath.split("/")[-1][:-4]
 
         self.data = topas2numpy.BinnedResult(self.filepath)
         bins = [dim.n_bins for dim in self.data.dimensions]
@@ -23,7 +23,6 @@ class Simulation:
         axdict = {0: "X", 1: "Y", 2: "Z"}
         databin_index = bins.index(max(bins))
         self.direction = axdict[databin_index]
-
         self.axis = np.array(self.data.dimensions[databin_index].get_bin_centers())
         unit = self.data.dimensions[databin_index].unit
         if self.direction == "Z":
@@ -54,12 +53,10 @@ class Simulation:
                     self.std_dev = self.std_dev / np.sqrt(self.histories)
             else:
                 std_dev = np.array([])
-        self.norm_std_dev = self.std_dev / max(self.dose)
-        self.norm_dose = self.dose / max(self.dose)
 
         if self.direction == "Z":
             self.params = pdd.calculate_parameters(
-                self.axis, self.norm_dose, self.norm_std_dev
+                self.axis, self.dose / max(self.dose), self.std_dev / max(self.dose)
             )
         else:
             self.axis = np.array(
@@ -67,24 +64,37 @@ class Simulation:
             )
             self.axis = self.axis.tolist()
             self.params = dp.calculate_parameters(
-                self.axis, self.norm_dose, self.norm_std_dev
+                self.axis, self.dose / max(self.dose), self.std_dev / max(self.dose)
             )
+
+        self.normpoint = max(self.dose)
         self.axis = {True: self.axis[len(self.axis) // 2 :], False: self.axis}
-        self.dose = {
-            True: {
-                True: self.norm_dose[len(self.norm_dose) // 2 :],
-                False: self.dose[len(self.dose) // 2 :],
-            },
-            False: {True: self.norm_dose, False: self.dose},
-        }
+        self.dose = {True: self.dose[len(self.dose) // 2 :], False: self.dose}
         self.std_dev = {
-            True: {
-                True: self.norm_std_dev[len(self.norm_std_dev) // 2 :],
-                False: self.std_dev[len(self.std_dev) // 2 :],
-            },
-            False: {True: self.norm_std_dev, False: self.std_dev},
+            True: self.std_dev[len(self.std_dev) // 2 :],
+            False: self.std_dev,
         }
 
     def convert_SI(self, val, unit_in):
         SI = {"mm": 0.001, "cm": 0.01, "m": 1.0, "km": 1000.0}
         return val * SI[unit_in] / SI["mm"]
+
+
+class EGSSimulation:
+    def __init__(self, filepath):
+
+        self.filepath = filepath
+        self.filename = self.filepath.split("/")[-1][:-7]
+
+        self.direction = ""
+        self.unit = ""
+        self.dose = []
+        self.std_dev = []
+        self.axis = []
+
+        self.axis = {True: self.axis[len(self.axis) // 2 :], False: self.axis}
+        self.std_dev = {
+            True: self.std_dev[len(self.std_dev) // 2 :],
+            False: self.std_dev,
+        }
+        self.normpoint = max(self.dose)
