@@ -8,7 +8,13 @@ class Text:
 
         self.add = {"de": "Daten hinzufügen", "en": "Add Data"}
         self.axis = {"de": "Achse", "en": "Axis"}
+        self.caxcorrection = {
+            "de": "Zentralstrahlkorrektur",
+            "en": "Center axis correction",
+        }
+        self.centeraxis = {"de": "Zentralstrahl", "en": "Center axis"}
         self.changefilename = {"de": "Neuer Name:", "en": "New Name:"}
+        self.choosenormalization = {"de": "Normieren auf ...", "en": "Normalize to ..."}
         self.close = {
             "de": "Derzeitige Ansicht schließen",
             "en": "Close current project",
@@ -20,9 +26,12 @@ class Text:
         self.dark = {"de": "Dunkel", "en": "Dark"}
         self.decrease = {"de": "Verkleinern", "en": "Decrease"}
         self.dp = {"de": "Dosisquerverteilung", "en": "Dose profile"}
+        self.egs = {"de": "EGS Simulationsdateien", "en": "EGS Simulation Data"}
         self.end = {"de": "Beenden", "en": "Close"}
         self.english = {"de": "Englisch", "en": "English"}
+        self.errorbars = {"de": "Fehlerbalken anzeigen", "en": "Show error bars"}
         self.file = {"de": "Datei", "en": "File"}
+        self.flank = {"de": "Flanke", "en": "Flank"}
         self.fullscreen = {"de": "Vollbild", "en": "Fullscreen"}
         self.fwhm = {"de": "HWB", "en": "FWHM"}
         self.german = {"de": "Deutsch", "en": "German"}
@@ -52,22 +61,29 @@ class Text:
         self.light = {"de": "Hell", "en": "Light"}
         self.loadmeasurement = {"de": "Messung laden", "en": "Load measurement"}
         self.loadsim = {"de": "Simulationsergebnis laden", "en": "Load simulation"}
+
         self.marker = {"de": "Symbolgröße", "en": "Marker Size"}
         self.markerline = {"de": "Liniendicke", "en": "Line Width"}
         self.measurement = {"de": "Messung", "en": "Measurement"}
         self.measurementdata = {"de": "Messdaten", "en": "Measurement Data"}
+        self.maximum = {"de": "Maximum", "en": "Maximum"}
         self.normalize = {"de": "Normieren", "en": "Normalize"}
+        self.normalization = {"de": "Normierung", "en": "Normalization"}
         self.options = {"de": "Optionen", "en": "Options"}
         self.orr = {"de": "oder", "en": "or"}
         self.pdd = {"de": "Tiefendosiskurve", "en": "Depth dose"}
         self.ptw = {"de": "PTW tbaScan", "en": "PTW tbaScan"}
         self.revert = {"de": "Rückgängig", "en": "Undo"}
         self.save = {"de": "Graph abspeichern", "en": "Save graph"}
+        self.scanaxis = {
+            "de": "Scanrichtung: [X = Ja | Y = Nein]",
+            "en": "Scan axis: [X = Yes | Y = No]",
+        }
         self.simulation = {"de": "Simulation", "en": "Simulation"}
-        self.simulationdata = {"de": "Simulationsdateien", "en": "Simulation Data"}
         self.startdark = {"de": "Im dunklen Modus starten", "en": "Start in dark mode"}
         self.submit = {"de": "Fertig", "en": "Sumbit"}
         self.symmetry = {"de": "Symmetrie", "en": "Symmetry"}
+        self.topas = {"de": "TOPAS Simulationsdateien", "en": "TOPAS Simulation Data"}
         self.view = {"de": "Ansicht", "en": "View"}
         self.window_title = {
             "de": "TopasMC Simulationsauswertung",
